@@ -6,5 +6,6 @@ del sys
 from .core import (mod_tower,)
 
 __all__ = [
-    'mod_tower'
+    'mod_tower',
+    'testing'
 ]
\ No newline at end of file
